#
# Copyright (c) 2021-2024 SUSE LLC
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           klog
Version:        2.3.4
Release:        1.18
Summary:        Hamradio logging program
License:        GPL-3.0-only
Group:          Productivity/Hamradio/Logging
URL:            https://www.klog.xyz
Source0:        https://github.com/ea4k/klog/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        klog.png
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  dos2unix
BuildRequires:  pkgconfig(Qt5Charts)
BuildRequires:  pkgconfig(Qt5Core) >= 5.10
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(hamlib)
BuildRequires:  pkgconfig(Qt5Positioning)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5SerialPort)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  cmake(Qt5LinguistTools)


%description
KLog is a hamradio logging program that can be executed in several
operating systems!

%prep
%setup -q -n %{name}-%{version}

%build
qmake-qt5 PREFIX=/usr
%make_build

%install
install -Dm 0755 src/build/target/%{name} %{buildroot}%{_bindir}/%{name}
install -Dm 0644 src/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
install -d %{buildroot}%{_datadir}/klog/translations
install -m 0644 src/build/target/translations/*.qm %{buildroot}%{_datadir}/klog/translations

# install desktop file
%suse_update_desktop_file -c klog Klog "HAM radio logging program" klog klog "Network;HamRadio"

%files
%license COPYING
%doc src/AUTHORS src/Changelog src/TODO src/README src/NEWS
%{_bindir}/%{name}
%{_datadir}/klog
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Sun Mar  3 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Mar 2024 - 2.3.4
  BugFix: After Editing a QSO, lotw_qsl_rcvd is emptied (Closes #656,
    [#659]) (TNX N6PAZ, EA5WA)
  Bugfix: Keep data of SAT tab when entering a QSO stopped working.
    (TNX EA5WA)
  BugFix: When editing a split QSO, if TX Frequency is modified,
    split is disabled and frequencies made equal. (EA5WA)
  BugFix: Incorrect CQ zone saved to DataBase (Closes #666) (EA5WA)
  BugFix: FO/x calls are not properly identified/stored (Closes #677)
    (EA5WA)
  BugFix: Minor CQz & ITUz bugfixes that could, potentially accept
    CQ or ITU zones being 0.
  Bugfix: Several fields do not meet ADIF specification (Closes #669)
  Bugfix: DX-Cluster activity file can't be edit with normal txt
    file. (Closes #682)
  Bugfix: QSO_COMPLETE field in database needs to be redefined
    (Closes #680)
  Bugfix: QRZ.com QSO status was not properly working. (Closes #664)
  Bugfix: Alternative location for logbook.dat was not working
    properly (Closes #653)
  Bugfix: Clarify how to use mode / submode in the DB (Closes #650)
  Bugfix: Cleared some warning errors about the DB notbeing created
    in the console.
  Enhancement: Refactored the getADIFQSO/getADIFFromQSOQuery to have
    just one single point of ADIF creation.
  Translations: Danish (TNX Peter), Russian (YL3GBC), Spanish (EA4K)
- Fixed source location
* Sun Dec 31 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Dec 2023 - 2.3.3
  WIP: Started to reduce the possibility of SQLi with the use of
    prepared statements.
  Bugfix: Sat QSO edit was not showing the worked SAT (Closes #645)
  Bugfix: After editing a QSO, the restore was not working properly.
    (Closes #649)
  Bugfix: In Sat QSO, still not selected band may make the QSO
    unusable. (Closes #651)
  Bugfix: All Gridsquares are now listed when Export to ADIF is
    used. (Closes #514)
  Bugfix: Selecting a sat with a new band made the bandcombobox
    unusable. #613
  Bugfix: F1 (online manual link fixed (Closes #627) (TNX ikbenkous)
  Bugfix: 'Usage' does not properly handle arguments, print
    newlines or return status codes (Closes #625) (TNX ikbenkous)
  Enhancement: Improved the Frequency entry. (Closes #622) (TNX
    ikbenkous)
  Enhancement: Use a good discriminator in header guards (Closes
    [#624]) (TNX ikbenkous)
* Thu Jun 29 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Jun 2023 - 2.3.2
  Bugfix: KLog was not starting when started in clean installations.
    (Closes #599)(TNX cwross)
- Jun 2023 - 2.3.1
  Bugfix: When exporting a log, selecting the stationcallsign has no
    efect on the qsos shown
  Bugfix: When no validating callsigns, some ADIF fields were exported
    even if they were empty.
  Bugfix: In some conditions, not identified propagation modes were
    exported as "NO". (Closes #518)
  Bugfix: VUCC_GRIDS validation was not properly done.
  Bugfix: It was not possible to select the second pair of freqs of
    a Sat (Closes #483)
  Bugfix: Export/Upload lists of QSOs where not properly created due to
    call validation issues. (Closes #528)
  Bugfix: Fixed the ClubLog URLs that were changed by ClubLog. (Closes #502)
  Bugfix: QSOs confirmed with LoTW were not properly shown in DXCC
    Status. (Closes #551)(EA5WA)
  Bugfix: In some conditions, not identified propagation modes were
    exported as "NO".
  Bugfix: In some conditions QRZ.com log upload was not working. (Closes #542)
  Bugfix: In some conditions eQSL.cc log upload was not working. (Closes #526)#
  Bugfix: VUCC_GRIDS validation was not properly done.
  Bugfix: It was not possible to select the second pair of
    freqs of a Sat (Closes #483)
  Bugfix: LoTW export was not using the selected grid when
    exporting (Closes #539)
  Bugfix: Some statistic widgets had a broken layout (Closes #491)
  Bugfix: When a new QSO is added, the numbers in awardswidget
    were not updated.
  Bugfix: Distance/beam is shown when editing. (Closes #330)
  Improvement: Inclusive search and submodes in LoTW download and
    WSJTX import. (TNX AG5UR)
  Improvement: Code improvement in the MainWindowInputQSO class.
  Improvement: Log export widget shows now only QSOs in the current log.
  Improvement: Code improvement in the MainWindowInputQSO class.
  Improvement: Warning of unused parameters removed.
  Improvement: Some SQL queries optimized for speed.
  Improvement: Optimized the way log files are exported to online
    services.
  UI: Added QRZ Lookup Button (Closes #390) (EA5WA).
  UI: Removed the locator, TX Freq and RX freq widgets from the
    Satellite tab. (Closes #534, 535, #536)
  UI: Shows the total number of QSOs when exporting.
  UI: Added a Right-click menu in the DXCluster widget to send a
    spot to QRZ.com.
  UI: Columns in LogView are now movable with the mouse.
  Removed the user callsign from the http header when checking for
    a new version for increased privacy.
  Translations: Catalan (TNX Txema), Latvian (TNX YL3GBC), Spanish
    (EA4K), Ukrainian (UR6QV & UR3QJW).
* Mon Oct 24 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Oct 2022 - 2.3
  Improvement: Code optimization (TNX JohnS0819)
  Bugfix: Calls like EA4K/P were not identified as EA.
  Bugfix: Adding DXCluster servers was failing. (Closes #492) (TNX EA7IXM)
  Bugfix: When accepting changes on Settings, the settings were being
    readed twice, causing errors an delays. (Closes #495)
  Bugfix: QSOS with a lotw_qsl_sent status as NULL where not identified
    when queuing QSOs for LoTW. (closes #514)
  Improvement: Added the modes and propagation modes of ADIF 3.1.3
    (Closes #509, #510)
  Improvement UI: Freq & RST labels have been reorganized for clarity.
  Improvement: Windows package updated to hamlib 4.4.
  Improvement: Minor UI changes in the Setup->misc tab.
  Improvement: Showing seconds in the QSO edit can be selected by the user.
  Improvement: LoTW upload process allows the user to select a
    specific locator to be uploaded to be matched with TQSL locations.
  Improvement: Changed how hamlib is initialized to speed-up the
    setup widget exit, specially for non-hamlib users.
  Improvement: Some code cleaning.
  Improved and more frequent hash implementations by @JohnS0819 in #485
* Mon Sep  5 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Aug 2022 - 2.2.1
  Bugfix: Temporary bugfix for Setup eLog Page preventing crash on start.
  (Closes #489)
  Bugfix: Temporary quick fix to prevent call validation in some
  classes that may cause errors. (Opens #490)
  Bugfix: Config for real time for clublog was not properly managed.
  Bugfix: Calls like EA4K/MM were identified like Scotland, not maritime.
  Improvement: Code improvement in the Setup of eLogs.
  Tests: Tests for SetupPageElog added.
* Tue Aug 23 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Aug 2022 - 2.2
  Bugfix: DL was not properly shown in the DXCC status table (Closes #460) (TNX N6PAZ)
  Bugfix: Clublog QSO status export to file was not properly done.
  Bugfix: Removing first char in the callsign caused a crash. (Closes #455) (TNX G4MKT)
  Bugfix: Database was not beig properly created in first start.
  Bugfix: Changing the statistic widget crashed KLog. (Closes #484)
  Bugfix: Some prefixes were not properly identified.
  Bugfix: Fixed some database column name typos.
  Improvement: Callsign identification optimized.
  Improvement: The Debug logging has been improved, still much work TBD.
  Improvement: General code cleaning (coveralls.io)
  Improvement: General code cleaning (lgtm.com alerts)
  Improvement Distance is now stored for new QSO added or modified
  QSOs from the UI. (Closes #459).
  Map back to OSM to recover the map for raspberry & linux
  Translations: Spanish (EA4K).
* Sat Mar 19 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
  Feb 2022 - 2.1
  Improvement: Changed the map provider to ESRI to be able to get Map legends in English.
  Improvement: Added two buttons to the map to change the zoom level.
  New feature: DX Spots coming from DXCluster can be sent to the map.
  Bugfix: Longitude was not properly calculated from a callsign.
  Translations: Spanish (EA4K).
  Feb 2022 - 2.0
  Stop the Ukranian war release.
  This KLog release is showing author's request to stop the war in Ukraine.
  No other feature of bugfix will be done in this release.
  Feb 2022 - 1.9
    New feature: Map showing locators. (Closes #168)
    Bugfix: Mark QSL to be sent is not shown if QSL is sent on right
    click menu in the search widget. (Closes #387).
    Improvement: Query the radio after leaving manual mode (Closes #416).
    Improvement: Grids are now sorted on Grid stats for satellites. (Closes #424).
    Translations: Catalan (TNX Txema), Italian (TNX IU5HIU), Japanese
    (TNX JJ1TGT) & Spanish (EA4K).
* Fri Jan 28 2022 Mariusz Woźniak <sp6ina@c44.pl>
  Jan 2022 - 1.8.7
    Bugfix: Removed the hamlib test from the KLog start that was causing big delays.
    Bugfix: Serial speed was not saved to config file.
    Bugfix: eQSL Uploads problem solved (Closes #406).
    Bugfix: Connection to the radios were not being done properly (Closes #407) (Closes #379).
    Bugfix: SplitCheckBox was checked when coming from Setup (Closes #377).
    Bugfix: Entering a QRZ cleared the DX Gridsquare if it was previously entered (Closes #357).
    Bugfix: Imported QSOs add the default electronic QSL send info if configured.
    Bugfix: DXCC widget shows last Entity status after modifying a QSO (Closes #412).
    Bugfix: Hamlib is now stopped while editing a QSO (Closes #414).
    Bugfix: Hamlib on serial devices works ok. (Closes #355).
    Bugfix: RST is not changed on mode change when editing. (Closes #423).
    New feature: Added a Manual Mode checkbox to disable quickly hamlib & wsjtx integration.
    New feature: Added "Save" and "Cancel" button when editing a recorded QSO.
    Update: Developers mailing list address changed to klog@groups.io (Closes #421).
* Sat Jan  8 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
  Jan 2022 - 1.8.6
- Bugfix: Net rig & FLRig hamlib connections were not working propertly. (Closes #339) (TNX W5PNY)
- Bugfix: Some prefixes were not properly detected. (Closes #371) (Closes #367).
- Bugfix: Serial Hamlib rigs were not properly working. (TNX W5PNY)
- Bugfix: QRZ.com was disabled if user was not subscribed. (TNX EA5WA)
- Bugfix: QRZ.com data was not updated if the boxes were already filled. (TNX EA5WA)
- Bugfix: Callsigns formet were not always properly checked.
- Improvement: Hamlib 4.4 in binary packages (macOS & Windows) tested also in Linux.
- Improvement: RTS & DTR are defined to OFF by default in hamlib.
- Improvement:KLog differenciates QRZ.com subcribed users from non subscribed. (TNX EA5WA)
* Thu Oct  7 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
  Oct 2021 - 1.8.5
- Bugfix: Station callsign was not shown on window title. (Closes #347)
- Bugfix: Received QSOs from LoTW were shown as to be sent. (Closes #358)
- Improvement: Message of the mainwindow has been updated. (Closes #361)
- Improvement: Logs to be uploaded to LoTW are only shown from the current log. (Closes #362)
- Improvement: Logs to be uploaded to ClubLog are only shown from the current log. (Closes #363)
- New feature: It is now possible to enable/disable the callsign check. (Closes #186)
- Removed dead & commented code.
- Improved how mainCallsign & Station callsigns are used.
- QRZ.com queries are disabled if QRZ.com returns a non-subscribed user answer.
- patch klog-0001-fix-worldmapwidget.patch removed (applied upstream)
* Thu Sep 16 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- added a patch klog-0001-fix-worldmapwidget.patch to fix build for
  Leap 15.2 and 15.3
* Thu Sep 16 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
  Aug 2021 - 1.8.4
- Bugfix: In some situations callsigns were always shown as to be worked. (Closes #345)
- Bugfix: Double click on DXCC widget was not sending the DXCC QSOs to the search widget.
- Bugfix: Queued LoTW  were not properly selected for upload. (Closes #354) (TNX EA5WA)
- Improvement: KLog start is optimized.
  Aug 2021 - 1.8.3
- Added some backport code so systems without Qt 5.15.2 can compile and use KLog.
- Bugfix: Selecting File->Export to ADIF was not showing all the possible QSOs to be exported.
  Aug 2021 - 1.8.2
- Bugfix: Updated the openSSL libraries for Windows users that was causing TLS errors on some connections. (Closes #342)
- Bugfix: Spanish typo (TNX EA5WA) (Closes #341)
- Bugfix: Statistics were showing wrong numbers on DXCC/Grid per band (Closes #344)
  Aug 2021 - 1.8.1
- Bugfix: QSOs comming from WSJTX and other sources where not shown, depending on logview configuration. (Closes  #338)
  Aug 2021 - 1.8
- Bugfix: Some recently added ADIF fields where not properly imported from ADIF.
- Improvement: Code updated to Qt 5.15.2. (Closes #323)
- Improvement: VUCC_GRIDS & MY_VUCC_GRIDS are also managed in the UI. (Closes #319)
- Improvement: LogView fields to be shown can be selected in the prerefences. (Closes #23)
- Translations: Catalan (TNX Txema), Italian (TNX IU5HIU) & Spanish (EA4K).
* Sun Aug  1 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
  July 2021 - 1.7
- Bugfix: RealTime remained checked when editing.
- Bugfix: Some Hamlib parameters were not properly stored.
- Bugfix: Coredump when no entity (Closes #302)
- Bugfix: Colors are now properly defined. (Closes #275) (Closes #40)
- Bugfix: Station callsign is read from the settings. (Closes #307)
- Bugfix: The right setup dialog tab is open on first start. (Closes #311)
- Improvement: DarkMode added. (TNX EA5WA) (Closes #56)
- Improvement: DXCC & WAZ management optimization.
- Improvement: Current UI data is saved before going to edit a QSO and restore after editing.
- Improvement: Order of widgets when tab is pressed has been improved. (Working on #265)
- Statistics: Added the Grids & DXCC per band statistic. (Closes #312), (Closes #313), (Closes #314)
- UI: The Setup menu has been moved to Settings into the File menu.
- Translations: Catalan (TNX Txema), Italian (TNX IU5HIU) & Spanish (EA4K).
  June - 1.6
- Optimization: Isolated the QSO tab to an independent widget.
- Bugfix: When starting KLog for the first time, it crashed.
- Bugfix: Hamlib was not properly started on KLog start (closes #126) (TNX G4MKT)
- Bugfix: SAT_MODE was being added to non SAT QSOs.
- Bugfix: DXCC status was not being properly updated.
- Improvement: Added user selectable ADIF fields in the Other and My Data tabs. (Closes #4)
- Improvement: Enhanced how the UDP server is started on KLog start.
- Improvement: Added some basic SQL Injection protection to the UI. (Closes #95)
- Improvement: UI data is saved before entering the Setup and restored after setup is done. (Closes #188)
- Improvement: Only one instance of KLog is allowed to run simultaneously. (Closes #250) (TNX foldynl)
- Commented some Flawfinder false positives.
- Translations: Catalan (TNX Txema), Czech (TNX OK1MLG), Italian (TNX IU5HIU) & Spanish (EA4K).
* Thu Jun 10 2021 sp6ina@c44.pl
  May 2021 – 1.5.3
  – Bugfix: Fixes the DataBase update process to add the Q65 mode.
  – Bugfix: Unexpected Setup dialog behavior. (Closes issue #178) (TNX foldynl)
  – Bugfix: Time is not in UTC when „Log in real time” is uncheck. (Closes issue #179) (TNX foldynl) – Bugfix: Missing translation in SoftwareUpdateDialog. (Closes issue #180) (TNX foldynl)
  – Bugfix: Inconsistency text in Tip#2. (Closes issue #182) (TNX foldynl)
  – Bugfix: Missing Translation string in SetupPageMisc::createUI. (Closes issue #185) (TNX foldynl)
  – Bugfix: When LoTW service was no enabled, KLog insisted to show the QSOs to be exported.
  – Bugfix: Setup->Satellites did not show a correct Short name. (Closes issue #192) (TNX foldynl) – Bugfix: Removal DX Cluster unexpected disconnection. (TNX foldynl)
  – Bugfix: Tip #21 was not shown. (Closes issue #184) (TNX foldynl) – Bugfix: TQSL was not properly found on macOS. (Closes issue #195) (TNX K0JM)
  – Enhancement: Improved the readability of the DX Cluster window. (TNX foldynl)
  – Updated the KLog tips.
  – Translation: Czech (TNX OK1MLG), Spanish.
* Mon May 10 2021 sp6ina@pzk.pl
  Update to - 1.5.2
    Bugfix: Complex calls like K/EA4K/P were identified as wrong calls. (Closes issue #177) (TNX PA3FNT)
    Added the GitHub repository to find new releases due to the issue with savannah.nongnu.org
    New feature: F4 toggles the real time status (on/off).
    Improvements on call identification management on user input.
    Bugfix: Editing removes QTH and name (Closes issue #113)
    Bugfix: Some complex calls (i.e. F/EA4K) were causing a crash unders some conditions.
    Bugfix: DX Entity of some complex calls where not properly identified. (Closes issue #8).
* Wed Mar 31 2021 sp6ina@pzk.pl
  Update to - 1.5
- Added the 8M & 5M bands.
- New feature: Added "Adif file deletion" checkbox. User can choose to show or not the message boxes after uploading QSOs.
- New feature: New function added to fill automatically the satMode field in satellites Tab depending on upload/download frequencies.
- UI: Added EA5WA as Author. :-)
- New feature: LoTW confirmation is also counted for DXCC & WAZ.
- New feature: DUPES are now identified when coming from WSJTX, ADIF logs, LoTW logs or simply adding a QSO.
- New feature: Added a time period to consider a QSO as DUPE if call, band & mode are also the same. (Closes issue#41)
- Improvement: Hamlib now supports network communication (TNX DG1VS)
- Improvement: Optimized the way DXCC & WAZ are managed.
- Improvement: KLog receives the clear messages from WSJTX and is able to clear the KLog UI.
- Statistics: Added the Grids on Satellites statistics.
- Statistics: Added the DXCC on Satellites statistics.
- UI: Removed the QComboBox of the Setup Log tab to select the log. (TNX G4MKT)
- UI: Added the QSO per log in the logs setup.
- UI: Added a checkbox to keep the Propagation mode, if needed. Propagation mode is also linked to the Satellite tab. (TNX EA5WA)
- UI: Added a Help->Online Manual menu or push F1 to go to the Online Manual (Closes issue #52)
- Bugfix: Improved the way the QSOs come from WSJT-X. (EA5WA)
- Bugfix: Double clicking on a call, while searching made the search to be redefined to that call and the previous search was lost.
- Bugfix: Satellite stats where not properly calculated. (TNX EA5WA)
- Bugfix: Identifying some bands was not properly done due to the names being in lower case.
- Bugfix: When importing an ADIF and asking for a default station callsign, it was only used for the first QSO, leaving the rest without a station callsign.
- Bugfix: Stats widget where not being properly created.
- Bugfix: The Log combobox on the Statistics was not working. (TNX EA5WA)
- Bugfix: End date tooltip updated on the export widget.(TNX G4MKT)
- Bugfix: DX Locator tooltip was not OK. (TNX G4MKT)
- Translations: Catalan (TNX Txema) & Spanish (EA4K).
* Sun Feb  7 2021 sp6ina@pzk.pl
- Bugfix: Improved the way the QSOs come from WSJT-X. (EA5WA)
- UI: Changed QRZ to Callsign.
* Tue Dec 15 2020 sp6ina@pzk.pl
- Improvement: Prepared the WSJTX-2.4 UDP interface.
- Improvement: User data stored in the setup is know used in the QSOs (default power, station callsign).
- Improved the KG4xx (Guantanamo bay) DXCC detection from KG4 calls.
- Updated how KLog counts the confirmed DXCC entities to include LoTW confirmations.
- New feature: QSO upload to the QRZ.com Logbook (including qso selection and qso mark that has been uploaded)
- New feature: QSO upload to the eQSL.cc Logbook (including qso selection and qso mark that has been uploaded)
- New feature: ClubLog full log upload (adding or overwriting).
- New feature: It is possible to keep the comment field from one QSO to the following one. (TNX EA5WA)
- New feature: It is possible to select multiple QSOs in the log and execute several actions with the selected QSOs.(TNX EA5WA)
- New feature: It is possible to check for the data of calls in QRZ.com (you need a subscription in QRZ.com)
- UI: Removed the Keep my data option from the Setup UI.
- UI: The RX frequency follows the TX unless the split is checked.
- UI: Consolidation of all the electronic logs configurations in one single setup page into the eLog tab.
- Bugfix: Save all QSOs to ADIF process continued even if the user clicked in cancel.(TNX G4MKT)
- Bugfix: Backup file was not being created in the right path.(TNX G4MKT)
- Bugfix: Some paths were converted to upper case causing some issues in some case sensitive situations. (TNX G4MKT)
- Bugfix: In some cases, the RST format was not properly defined.(TNX G4MKT)
- Bugfix: Default ADIF file was not being saved on exit. (TNX G4MKT)
- Bugfix: It was not possible to select empty logs from the preferences. (TNX G4MKT)
- Bugfix: QSOs comming from WSJTx were not being uploaded to ClubLog. (TNX PD9Q)
- Bugfix: Too many mesages when uploading in realtime to Clublog. It should be done silently.(TNX EA5WA)
- Bugfix: Typo in the INSTALL-linux. (TNX DL4TO)
- Bugfix: Hamlib polling rate was not being saved from the setup. Default value is defined to 300ms. (TNX G4MKT)
- Bugfix: Complete with previous QSO (name, locator, ...) was not working properly.
- Bugfix: PROGRAMID ADIF data was not properly tagged.
- Bugfix: When selecting the QSOs to upload to LoTW, if the selected call was the first one on the combobox, selection didn't worked properly.
- Bugfix: When importing ADIF files with fields without RST_SENT or RST_RCVD the proposed default value was not adapted to the mode of that QSO.
- Bugfix: Extension .adi was always added, even if the file had it already.
- Bugfix: When doing a database backup, the name of the file was not being properly defined.
- Bugfix: ClubLog realtime syncronization was not working properly.
* Sat Oct  3 2020 sp6ina@pzk.pl
  October – 1.3
  – Improved the search widget to make searching much quicker.
  – Improved the Edit of QSO related to the default QSL sent status.
  – Improved the QRZ.com & DXHeat.com queries from the log & search window.
  – Improved the UDP datagram receiver to ensure it is working multicast.
  – UI: KLog remembers the size of the window from last execution. (TNX EA5WA)
  – UI: The Station Callsign and number of QSOs in the current log is shown in the windows title.(TNX G4MKT)
  – New feature: KLog now search for the call as the user enters for previously QSOs with that call. (TNX EA5WA)
  – Adds an „.adi” file extension to the log ADIF files if not added by the user. (TNX G4MKT)
  – When reading a log from LoTW, if there are new QSOs not present on the current logfile, KLog offers the option to import them.
  – Bugfix: It was not possible to add a log if the date and Station Callsign were the same. Now operators and comments are also taken into consideration.(TNX G4MKT)
  – Bugfix: The export of QSOs without an station callsign defined was failing.(TNX G4MKT)
  – Bugfix: When reading a log from LoTW, the list of QSOs were not shown at the end. (TNX EA5WA)
  – Bugfix: Comment in the new log widget was converted to uppercase. (TNX G4MKT)
  – Translations: Catalan (TNX Txema), Italian (TNX IU5HIU), Spanish (EA4K)
* Mon Aug 31 2020 sp6ina@pzk.pl
  Aug 2020 - 1.2.1
- Bugfix: ADIF export was not exporting dates with the right format in some eQSL fields.
- Bugfix: QSOs were not properly imported when received from WSJT-X.
- Bugfix: Pool/Poll typo fixed. (TNX Barry!).
- Bugfix: QSO editing - Locator was being cleared from sat tab.
- Bugfix: QSO editing - User Inferface was not properly clearedn after editing.
- Bugfix: QSOs tag in the Award tab was not properly formatted in Windows OS.
- Improvement: ADIF creation has been optimized.
- Improvement: All fields received from WSJTX are now added to the log.
- Improvement: GRIDSQUARE & MY_GRIDSQUARE ADIF fields are now also exported to LoTW upload.
* Thu Aug  6 2020 sp6ina@pzk.pl
  Update Aug 2020 – 1.2
    New feature: KLog proposes to do a database backup before it is upgraded so data can be recovered if there is any problem.
    Improvement: When receiving the status from WSJT-X the RX frequency is also updated with the same TX freq.
    Improvement: Dates and Times are now together and it is possible to sort the log based on date & time. Date format has been overall updated.
    Improvement: Search is now more confortable as the search does not start inmediately after a key is pressed but some time after so it’s possible to enter more letters and reduce the search time.
    Bugfix: Fixed the DB update processes.
    Translations: Catalan (TNX Txema), Italian (TNX IU5HIU), Spanish (EA4K).
* Fri Apr 24 2020 sp6ina@pzk.pl
- Update to version 1.0.1
    New feature: Integrate TQSL to upload QSOs to LoTW directly from KLog.
    UI: Removed the first column inthe DXCC widget to make it more user friendly.
    UI: Created a widget to manage the Main QSO entry to make KLog more modular.
    UI: eQSL & LoTW are marked as queued to be sent by default if the user activates it in the setup.
    UI: Added the title to some QMessage boxes that were missing.
    UI: Improved the usability of creating new logs or editing existing logs in the setup.
    New feature: Integrate TQSL to upload QSOs to LoTW directly from KLog.
    New feature: You can check a call in QRZ.com by right-clicking in the call from the log.
    New feature: You can check a call in DXHeat.com by right-clicking in the call from the log.
    New feature: It is now possible to save in a file all the DX-Cluster activity.
    Improvement: Added https to the cty.dat download.
    Improvement: Added the https to download.klog.xyz
    Improvement: Propagation modes are now sorted in the Propagation mode combobox.
    Improvement: Four new tips added.
    Improvement: eQSL & LoTW dates are updated always that are modified to any status.
    Improvement: If a QSO does not have a freq, a default freq based on the band is assigned if edited.
    Improvement: Removed some deprecated functions.
    Improvement: Improved the way KLog checks for a wrong call (IARU rules applied).
    Improvement: Improved the way KLog checks for a wrong IOTA reference.
    Removed the functionality to sort the log based on Date & Time columns.
    Removed one console message about a duplicated database connection.
    Bugfix: It was not possible to include new dxcluster servers in the setup.
    Bugfix: The default value of RST in some digital modes using SNR were not properly shown.
    Bugfix: In translated instances of KLog, Propagation mode was sometimes not properly saved when no propagation mode eas selected.
    BugFix: Locator in SAT widget was not always not correctly evaluated as correct.
    Updated translations: Catalan (TNX Txema), Croatian (TNX M0NKC), Finnish (TNX Kristjan), Spanish (EA4K).
* Fri Feb 28 2020 sp6ina@pzk.pl
- Update to version 0.9.9.1
  * UI: Created a widget to manage the Awards to make KLog more modular.
  * UI: When starting a new version for the first time, the splashscreen is not hidding other messages anymore.
  * UI: Removed some not used File menus (New, Open, Save & Save As).
  * UI: Sorting by date the log is also sorting taking into account the time.
  * New versions are now found depending on the OS, not just for the sources.
  * New feature: Added some tips in the Help menu to help the users to get the most of KLog.
  * Hamlib has now a read-only mode that will read freq & mode from the radio but will never modify/update anything in the radio.
  * Added some debug log option.
  * Some code cleaning with cppcheck and compilation warnings removed.
  * UI: Added a WSJT-X like color schema.
  * Bugfix: KLog was crashing if the call was completely removed in the Setup.
  * BugFix: KLog was always logging 59 instead of the real RST. (TNX DB4BIN)
  * BugFix: KLog was changing the mode in the radio from CW-R to CW if hamlib was active. (TNX G4MKT)
  * BugFix: KLog was changing freq in the radio in the starting process if hamlib was active. (TNX G4MKT)
  * Improvement: KLog reads the radio freq/mode when starting. (TNX G4MKT)
  * BugFix: ADIF export function was not exporting the DARC_DOK properly.
  * Bugfix: Closes Debian bug: #948911: FTBFS on mipsel. (TNX Lisandro)
  * BugFix: Editing the log metadata in the setup was not possible.
  * KLog exit process improved.
  * KLog start process improved.
  * DataProxy_SQLite class removed to optimize the code.
  * Other minor improvements.
  * Updated translations: Catalan (TNX Txema), French (F4HWL), Spanish (EA4K).
* Wed Sep 25 2019 sp6ina@pzk.pl
- Update to version 0.9.8.1
  * Added the Es’hail / QO-100 satellite.
  * UI: Satellite list, propagation modes and others are now shown sorted. (TNX Isabel)
  * UI: Added default values to the infoWidget (Continent, Prefix, CQ, ITU…). (TNX Isabel)
  * UI: RX/TX Freq in Satellite tab are also in red/black depending on the frequency being out/in of ham bands.
  * UI: Mode selected is now changing the RST format and default values for some modes.
  * Bugfix: Editing a QSO to remove a comment was not properly working. (TNX Isabel)
  * Bugfix: Worked & Confirmed QSO numbers are now aligned in the Awards tab. (TNX Isabel)
  * Bugfix: KLog.pro is now fixed to compile in Linux. (TNX KB2YSI)
  * Bugfix: Improved how the DXMarathon was managed when disabled.
  * Bugfix: Improved how DXCC Award was updated after one QSO was added. (TNX Isabel)
  * Fixed a bug in the SQL update database.
* Sun Sep  1 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.8
  * New feature: Basic Hamlib support.
  * Fixed a bug in the SQL update database.
  * Fixed a bug in the DXCCWidget.
  * Fixed a bug in the QSO per hour stats.
  * Added th FT4 mode.
  * Updated translations: Catalan, Danish, Finnish,French,German,
    Spanish.
* Tue Mar 19 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.7.2
  * Bugfix: Frequency boxes did not accepted frequencies higher
    than 99.999 MHz.
* Mon Mar 11 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.7.1
  * Bugfix: The frequency was not properly saved in the DB.
  * Bugfix: The QSO_DATE was not exported into ADIF.
* Sun Mar  3 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.9.7
  * Bugfix: When clicking on Check updates, the dialog froze.
  * Bugfix: Printing log is not longer showing band in the mode
    column.
  * Updated the default date on date boxes to the current date.
  * Improved the Frequency syncronization between Satellite tab and
    the main tab.
  * Improved how default mode is calculated.
  * Added Satellites widget in Setup.
  * Updated translations: Catalan, Danish, Finnish, French, German
    and Spanish
* Fri Feb 22 2019 Martin Hauke <mardnh@gmx.de>
- Run spec-cleaner
- Use %%qmake5 macro
* Sat Oct 28 2017 wk@ire.pw.edu.pl
- update to version 0.9.2.6
- new transmission modes and propagation modes
- ADIF 3.0.6 compatible
- improvements (mainly gui) and bugfixes
- new italian translation
- updated translations: english, spanish and apanese
* Thu Aug 10 2017 wk@ire.pw.edu.pl
- update to version 0.9.2.6
- Several improvements and bugfixes
- updated translations: croatian, japanese and spanish
* Sat Mar 18 2017 dl8fcl@darc.de
- update to version 0.9.2.5
  Full rewritten software based only in Qt
  see Changelog
* Sun Feb 16 2014 wk@ire.pw.edu.pl
- update to version 0.6.2
- fixed possible crash
- some GUI improvments
* Tue Sep 10 2013 dl8fcl@darc.de
- update to version 0.6.1
  Bug fix: Locator calculation
  GUI improvment in QRZ box
* Fri Feb 22 2013 dl8fcl@darc.de
- update to version 0.6.0
  Bugfixes, GUI improved
* Thu Jan 26 2012 dl8fcl@darc.de
- update to version 0.5.9, bugfix release
* Wed Dec 28 2011 dl8fcl@darc.de
- update to version 0.5.8
* Wed Dec  1 2010 dl8fcl@darc.de
- update to version 0.5.7
* Tue Aug  3 2010 dl8fcl@darc.de
- update to version 0.5.6
* Fri Mar  6 2009 dl8fcl@darc.de
- Fix for hamlib 1.2.9
* Sat Oct  4 2008 dl9pf@gmx.de
- src_dxspot_cpp__fix_no_return_in_nonvoid.diff
- Fix for Factory
* Sat Jun  7 2008 dg7gt@online.de
- Ready for OpenSUSE 11.0
* Mon Jun  2 2008 dg7gt@online,de
- update to version 0.4.4
* Sun Dec 17 2006 dg7gt@online.de
- initial spec file for openSUSE 10.2
